@@ -43,6 +43,7 @@ public:
         , _dad ( dad )
     {
         ostringstream cmd;
+        cmd << "unset http_proxy ;";
 
         ostringstream s;
         s << "test-proxy/" << testcase << "/environment";
@@ -268,6 +269,10 @@ TEST_CASE ( TEST_PROXY_ENV_kfgWithSchemaAndPort ) {
     TestRunner ( this, "kfg-with-schema-and-port" );
 }
 
+TEST_CASE ( TEST_PROXY_ENV_withTrailingSlash ) { // VDB-3329
+    TestRunner ( this, "env-with-trailing-slash" );
+}
+
 extern "C" {
     ver_t CC KAppVersion ( void ) { return 0; }
     rc_t CC KMain ( int argc, char * argv [] )  {
