@@ -51,6 +51,8 @@
 
 #include <sysalloc.h>
 
+#include "../../libs/vfs/path-priv.h" /* vpNameOrOID */
+
 TEST_SUITE(VManagerTestSuite);
 
 using namespace std;
@@ -316,16 +318,20 @@ public:
         VFSManagerSetBindingsFile(mgr, bindings);
         KDirectoryRemove(wd, true, bindings);
     }
-    rc_t Register(uint32_t id, const char* uri)
+    rc_t Register(uint32_t id, VPath* p) const
     {
-        VPath* p;
-        if (VFSManagerMakePath(mgr, &p, uri) != 0)
-           throw logic_error("ObjIdBindingFixture::Register: VFSManagerMakePath failed");   
         rc_t rc = VFSManagerRegisterObject(mgr, id, p);
         if (VPathRelease(p) != 0)
            throw logic_error("ObjIdBindingFixture::Register: VPathRelease failed");   
         return rc;
     }
+    rc_t Register(uint32_t id, const char* uri)
+    {
+        VPath* p;
+        if (VFSManagerMakePath(mgr, &p, uri) != 0)
+           throw logic_error("ObjIdBindingFixture::Register: VFSManagerMakePath failed");
+        return Register(id, p);
+    }
     rc_t GetById(uint32_t id, string& uri)
     {
         VPath* vp;
@@ -365,50 +371,51 @@ FIXTURE_TEST_CASE(ObjIdRegister, ObjIdBindingFixture)
 {
     SetUp(GetName());
     
-    REQUIRE_RC(Register(1, "ncbi-acc:acc1"));
-    REQUIRE_RC(Register(2, "ncbi-file:acc2"));
+//  REQUIRE_RC(Register(1, "ncbi-acc:acc1"));
+    REQUIRE_RC(Register(1, "ncbi-acc:acc1?tic=1"));
+    REQUIRE_RC(Register(2, "ncbi-file:acc2?tic=22"));
 }
 FIXTURE_TEST_CASE(ObjIdRegister_Found_Same, ObjIdBindingFixture)
 {
     SetUp(GetName());
     
-    REQUIRE_RC(Register(1, "ncbi-acc:acc1"));
-    REQUIRE_RC(Register(2, "ncbi-file:acc2"));
-    REQUIRE_RC(Register(1, "ncbi-acc:acc1")); // same name, no problem
+    REQUIRE_RC(Register(1, "ncbi-acc:acc1?tic=1"));
+    REQUIRE_RC(Register(2, "ncbi-file:acc2?tic=22"));
+    REQUIRE_RC(Register(1, "ncbi-acc:acc1?tic=1")); // same name, no problem
 }
 FIXTURE_TEST_CASE(ObjIdRegister_Found_Different, ObjIdBindingFixture)
 {
     SetUp(GetName());
     
-    REQUIRE_RC(Register(1, "ncbi-acc:acc1"));
-    REQUIRE_RC(Register(2, "ncbi-file:acc2"));
-    REQUIRE_RC_FAIL(Register(1, "ncbi-acc:acc11")); // name differs
+    REQUIRE_RC(Register(1, "ncbi-acc:acc1?tic=1"));
+    REQUIRE_RC(Register(2, "ncbi-file:acc2?tic=22"));
+    REQUIRE_RC_FAIL(Register(1, "ncbi-acc:acc11?tic=1")); // name differs
 }
 FIXTURE_TEST_CASE(ObjIdById_Found, ObjIdBindingFixture)
 {
     SetUp(GetName());
     
-    REQUIRE_RC(Register(123, "ncbi-file:acc123"));
-    REQUIRE_RC(Register(12, "ncbi-acc:acc12"));
-    REQUIRE_RC(Register(1, "ncbi-acc:acc1"));
+    REQUIRE_RC(Register(123, "ncbi-file:acc123?tic=3"));
+    REQUIRE_RC(Register(12, "ncbi-acc:acc12?tic=2"));
+    REQUIRE_RC(Register(1, "ncbi-acc:acc1?tic=1"));
     
     string uri;
     
     REQUIRE_RC(GetById(123, uri));
-    REQUIRE_EQ(uri, string("ncbi-file:acc123"));
+    REQUIRE_EQ(uri, string("ncbi-file:acc123?tic=3"));
     
     REQUIRE_RC(GetById(12, uri));
-    REQUIRE_EQ(uri, string("ncbi-acc:acc12"));
+    REQUIRE_EQ(uri, string("ncbi-acc:acc12?tic=2"));
     
     REQUIRE_RC(GetById(1, uri));
-    REQUIRE_EQ(uri, string("ncbi-acc:acc1"));
+    REQUIRE_EQ(uri, string("ncbi-acc:acc1?tic=1"));
 }
 FIXTURE_TEST_CASE(ObjIdById_NotFound, ObjIdBindingFixture)
 {
     SetUp(GetName());
     
-    REQUIRE_RC(Register(100, "ncbi-acc:acc1"));
-    REQUIRE_RC(Register(200, "ncbi-file:acc2"));
+    REQUIRE_RC(Register(100, "ncbi-acc:acc1?tic=1"));
+    REQUIRE_RC(Register(200, "ncbi-file:acc2?tic=1"));
     
     string uri;
     
@@ -433,30 +440,113 @@ FIXTURE_TEST_CASE(ObjIdByName_Found, ObjIdBindingFixture)
 {
     SetUp(GetName());
     
-    REQUIRE_RC(Register(11, "ncbi-acc:acc11"));
-    REQUIRE_RC(Register(21, "ncbi-file:acc21"));
-    REQUIRE_RC(Register(1, "ncbi-acc:acc1"));
+    REQUIRE_RC(Register(11, "ncbi-acc:acc11?tic=3"));
+    REQUIRE_RC(Register(21, "ncbi-file:acc21?tic=22"));
+    REQUIRE_RC(Register(1, "ncbi-acc:acc1?tic=1"));
     
     uint32_t id;
     
-    REQUIRE_RC(GetByUri(string("ncbi-acc:acc11"), id));
+    REQUIRE_RC(GetByUri(string("ncbi-acc:acc11?tic=3"), id));
     REQUIRE_EQ((uint32_t)11, id);
 
-    REQUIRE_RC(GetByUri(string("ncbi-file:acc21"), id));
+    REQUIRE_RC(GetByUri(string("ncbi-file:acc21?tic=22"), id));
     REQUIRE_EQ((uint32_t)21, id);
     
-    REQUIRE_RC(GetByUri(string("ncbi-acc:acc1"), id));
+    REQUIRE_RC(GetByUri(string("ncbi-acc:acc1?tic=1"), id));
     REQUIRE_EQ((uint32_t)1, id);
 }
 FIXTURE_TEST_CASE(ObjIdByName_NotFound, ObjIdBindingFixture)
 {
     SetUp(GetName());
     
-    REQUIRE_RC(Register(1, "ncbi-acc:acc1"));
-    REQUIRE_RC(Register(2, "ncbi-file:acc2"));
+    REQUIRE_RC(Register(1, "ncbi-acc:acc1?tic=1"));
+    REQUIRE_RC(Register(2, "ncbi-file:acc2?tic=2"));
     
     uint32_t id;
-    REQUIRE_RC_FAIL(GetByUri(string("ncbi-acc:acc2"), id));
+    REQUIRE_RC_FAIL(GetByUri(string("ncbi-acc:acc2?tic=1"), id));
+}
+
+FIXTURE_TEST_CASE(DontRegistrer_vpNameOrOID, ObjIdBindingFixture) {
+    SetUp(GetName());
+
+    String id;
+    CONST_STRING(&id, "1154149");
+
+    String tick;
+    CONST_STRING(&tick, "D2BE86BF-CCD4-4114-9C60-FCB5422C64F5");
+
+    VPath* p = NULL;
+    REQUIRE_RC(VFSManagerMakePath(mgr, &p, "ncbi-file:%S?tic=%S", &id, &tick));
+
+    REQUIRE(p);
+    REQUIRE(p-> path_type == vpNameOrOID);
+
+    REQUIRE_RC_FAIL(Register(1154149, p));
+}
+
+FIXTURE_TEST_CASE(RegistrerGoodPath, ObjIdBindingFixture) {
+    SetUp(GetName());
+
+    String id;
+    CONST_STRING(&id, "name.ext");
+
+    String tick;
+    CONST_STRING(&tick, "D2BE86BF-CCD4-4114-9C60-FCB5422C64F5");
+
+    VPath* p = NULL;
+    REQUIRE_RC(VFSManagerMakePath(mgr, &p, "ncbi-file:%S?tic=%S", &id, &tick));
+
+    REQUIRE(p);
+
+    REQUIRE_RC(Register(1154149, p));
+}
+
+FIXTURE_TEST_CASE(DontRegistrer_BadScheme, ObjIdBindingFixture) {
+    SetUp(GetName());
+
+    String id;
+    CONST_STRING(&id, "name.ext");
+
+    String tick;
+    CONST_STRING(&tick, "D2BE86BF-CCD4-4114-9C60-FCB5422C64F5");
+
+    VPath* p = NULL;
+    REQUIRE_RC(VFSManagerMakePath(mgr, &p, "file:%S?tic=%S", &id, &tick));
+
+    REQUIRE(p);
+
+    REQUIRE_RC_FAIL(Register(1154149, p));
+}
+
+FIXTURE_TEST_CASE(DontRegistrer_NoQuery, ObjIdBindingFixture) {
+    SetUp(GetName());
+
+    String id;
+    CONST_STRING(&id, "name.ext");
+
+    VPath* p = NULL;
+    REQUIRE_RC(VFSManagerMakePath(mgr, &p, "ncbi-file:%S", &id));
+
+    REQUIRE(p);
+
+    REQUIRE_RC_FAIL(Register(1154149, p));
+}
+
+FIXTURE_TEST_CASE(RegistrerGoodAccPath, ObjIdBindingFixture) {
+    SetUp(GetName());
+
+    String id;
+    CONST_STRING(&id, "ACC123");
+
+    String tick;
+    CONST_STRING(&tick, "D2BE86BF-CCD4-4114-9C60-FCB5422C64F5");
+
+    VPath* p = NULL;
+    REQUIRE_RC(VFSManagerMakePath(mgr, &p, "ncbi-acc:%S?tic=%S", &id, &tick));
+
+    REQUIRE(p);
+
+    REQUIRE_RC(Register(1154149, p));
 }
 
 //////////////////////////////////////////// Main
